@@ -560,6 +560,19 @@ class BasePoseMatrix(BasePoseList):
         vf = np.vectorize(sym.simplify)
         return self.__class__([vf(x) for x in self.data], check=False)
 
+    def stack(self):
+        """
+        Convert to 3-dimensional matrix
+
+        :return: 3-dimensional NumPy array
+        :rtype: ndarray(n,n,m)
+
+        Converts the value to a 3-dimensional NumPy array where the values are
+        stacked along the third axis.  The first two dimensions are given by
+        ``self.shape``.
+        """
+        return np.dstack(self.data)
+
     # ----------------------- i/o stuff
 
     def printline(self, *args, **kwargs):
@@ -579,9 +592,12 @@ class BasePoseMatrix(BasePoseList):
         :type unit: str
         :param file: file to write formatted string to. [default, stdout]
         :type file: file object
+        :return: the formatted value as a string
+        :rtype: str
 
         - ``X.printline()`` print ``X`` in single-line format
-        - ``X.printline(file=None)`` is a string representing the pose ``X`` in single-line format
+        - ``X.printline(file=None)`` is a string representing the pose ``X`` in
+          single-line format
 
         If ``X`` has multiple values, print one per line.
 
@@ -606,10 +622,10 @@ class BasePoseMatrix(BasePoseList):
         """
         if self.N == 2:
             for x in self.data:
-                base.trprint2(x, *args, **kwargs)
+                return base.trprint2(x, *args, **kwargs)
         else:
             for x in self.data:
-                base.trprint(x, *args, **kwargs)
+                return base.trprint(x, *args, **kwargs)
 
     def __repr__(self):
         """
