@@ -6,12 +6,16 @@ Created on Sun Jul  5 09:42:30 2020
 @author: corkep
 """
 
+from spatialmath import base
+import matplotlib.pyplot as plt
+import numpy as np
+
 # geom2d
 def plot_line():
     pass
 
-def plot_point():
-    pass
+
+    
     
 def intersect_lines():
     # return mindist and points if no intersect
